@@ -196,6 +196,13 @@ def includeme(config):
             'hook_init': _add_userdatas_custom_headers,
             'hook_add_row': _add_userdatas_code_compta,
             'foreign_key_name': 'userdatas_id',
+            "excludes": (
+                'name',
+                'type_',
+                '_acl',
+                'parent_id',
+                'parent',
+            ),
         }
     )
     config.register_export_model(
