@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Tasks used to compile treasury measures
 """
@@ -26,7 +25,6 @@ from endi.models.accounting.treasury_measures import (
 )
 from endi_celery.conf import (
     get_recipients_addresses,
-    get_setting,
 )
 from endi.models.accounting.income_statement_measures import (
     IncomeStatementMeasure,
@@ -396,9 +394,13 @@ class BaseMeasureCompiler(object):
                     )
                     grid_item.store_measure(measure)
                 else:
-                    logger.debug("Updating the order of the given measure {} :\
-                            was {} becomes {}".format(measure.label, measure.order,
-                            measure_type.order))
+                    logger.debug(
+                        "Updating the order of the given measure {} :"
+                        " was {} becomes {}".format(
+                            measure.label, measure.order,
+                            measure_type.order
+                        )
+                    )
                     measure.order = measure_type.order
                     self.session.merge(measure)
 
@@ -526,7 +528,7 @@ Comptes de résultat traités : {}
 
 ----
 enDI
-""".format(len(grids)/12)
+""".format(int(len(grids)/12))
 
     def get_cache_key_from_operation(self, operation):
         """
@@ -587,7 +589,9 @@ enDI
         setting the updated_at attribute
         """
         logger.debug(
-            u"  + Processing specific datas for child {}".format(self.__class__.__name__)
+            u"  + Processing specific datas for child {}".format(
+                self.__class__.__name__
+            )
         )
 
         # Calling parent to really process measures
@@ -596,15 +600,17 @@ enDI
 
         # Choosing which date has to be used
         date_to_set = None
-        if(self.upload.filetype ==
-            AccountingOperationUpload.SYNCHRONIZED_ACCOUNTING):
+        if(
+            self.upload.filetype ==
+            AccountingOperationUpload.SYNCHRONIZED_ACCOUNTING
+        ):
             date_to_set = self.upload.updated_at
         else:
             date_to_set = self.upload.created_at
 
         # Setting the date in the non void grids
         for grid in self.processed_grids:
-            if grid is not None :
+            if grid is not None:
                 grid.grid.updated_at = date_to_set
                 self.session.merge(grid.grid)
 
@@ -651,7 +657,7 @@ def send_success(request, mail_addresses, type_label, message):
         try:
             subject = MAIL_SUCCESS_SUBJECT.format(type_label)
             send_mail(request, mail_addresses, message, subject)
-        except:
+        except Exception:
             logger.exception("Error sending email")
 
 
@@ -667,7 +673,7 @@ def send_error(request, mail_addresses, type_label, message):
         try:
             subject = MAIL_ERROR_SUBJECT.format(type_label)
             send_mail(request, mail_addresses, message, subject)
-        except:
+        except Exception:
             logger.exception("Error sending email")
 
 
@@ -692,8 +698,10 @@ def _collect_operations(upload_id, data_type, upload_date):
 
     closure_day = 0
     closure_month = 0
-    if(config.get("accounting_closure_day") != None and
-            config.get("accounting_closure_month") != None):
+    if(
+        config.get("accounting_closure_day") is not None and
+        config.get("accounting_closure_month") is not None
+    ):
         closure_day = int("0" + str(config.get("accounting_closure_day")))
         closure_month = int("0" + str(config.get("accounting_closure_month")))
 
@@ -710,11 +718,13 @@ def _collect_operations(upload_id, data_type, upload_date):
     begining_day = temp_date.day
     begining_month = temp_date.month
 
-    ## Collecting operation for current exercice fiscal
-    current_exercice_begining_date = date(current_year, begining_month,
-            begining_day)
-    current_exercice_end_date = date(current_year, closure_month,
-            closure_day)
+    # Collecting operation for current exercice fiscal
+    current_exercice_begining_date = date(
+        current_year, begining_month, begining_day
+    )
+    current_exercice_end_date = date(
+        current_year, closure_month, closure_day
+    )
 
     # If closure day is not 31/12 we have an exercice overlaping two years
     if not (closure_day == 31 and closure_month == 12):
@@ -728,10 +738,10 @@ def _collect_operations(upload_id, data_type, upload_date):
         elif this_month == closure_month:
             if(this_day > closure_day):
                 today_is_after_the_closure = True
-            else :
+            else:
                 today_is_after_the_closure = False
         else:
-           today_is_after_the_closure = False
+            today_is_after_the_closure = False
 
         logger.info("Today is after the closure this year :\
                 {}".format(today_is_after_the_closure))
@@ -740,28 +750,30 @@ def _collect_operations(upload_id, data_type, upload_date):
         if today_is_after_the_closure:
             current_exercice_begining_date =\
                     current_exercice_begining_date.replace(year=current_year)
-            current_exercice_end_date = current_exercice_end_date +\
-                    relativedelta(years=1)
+            current_exercice_end_date = current_exercice_end_date + \
+                relativedelta(years=1)
         else:
             current_exercice_begining_date = current_exercice_begining_date -\
                     relativedelta(years=1)
-            current_exercice_end_date =\
-                    current_exercice_end_date.replace(year=current_year)
+            current_exercice_end_date = \
+                current_exercice_end_date.replace(year=current_year)
 
     logger.info("Current exercice start the {} and ends the\
             {}".format(current_exercice_begining_date,
                 current_exercice_end_date))
 
     current_exercice_operations = AccountingOperation.query().filter(
-        AccountingOperation.date.between(current_exercice_begining_date,
-            current_exercice_end_date)
+        AccountingOperation.date.between(
+            current_exercice_begining_date,
+            current_exercice_end_date
+        )
     ).all()
 
     logger.debug(u"{} operations\
             collected".format(len(current_exercice_operations)))
 
-    ## Adding last exercice operations if needed (dans les cas ou les report
-    ## d'à nouveau n'ont pas encore été fait)
+    # Adding last exercice operations if needed (dans les cas ou les report
+    # d'à nouveau n'ont pas encore été fait)
     # Only for synchronised  operations (remontée automatique)
     if(data_type != AccountingOperationUpload.SYNCHRONIZED_ACCOUNTING):
         return current_exercice_operations
@@ -776,10 +788,12 @@ def _collect_operations(upload_id, data_type, upload_date):
     if former_year_closure:
         closure_is_done = former_year_closure.active
 
-    logger.info(u"{} closure is done : {}".format(former_closure_year, closure_is_done))
+    logger.info(
+        u"{} closure is done : {}".format(former_closure_year, closure_is_done)
+    )
 
     if not closure_is_done:
-        ## Find date of last exercice
+        # Find date of last exercice
         last_exercice_begining_date = current_exercice_begining_date -\
             relativedelta(years=1)
         last_exercice_end_date = current_exercice_end_date -\
@@ -791,8 +805,10 @@ def _collect_operations(upload_id, data_type, upload_date):
 
         # Select operations from last "exercice"
         last_exercice_operations = AccountingOperation.query().filter(
-            AccountingOperation.date.between(last_exercice_begining_date,
-                last_exercice_end_date)
+            AccountingOperation.date.between(
+                last_exercice_begining_date,
+                last_exercice_end_date
+            )
         ).all()
 
         logger.info(u"Appending {} operations from last\
@@ -828,8 +844,9 @@ def compile_measures_task(self, upload_id, grid_type=None):
     if grid_type == "treasury":
         # We use created_at date, because his year is necessarily
         # into the requested exercice for computing the measures
-        operations = _collect_operations(upload_id, upload.filetype,
-            upload.created_at.date())
+        operations = _collect_operations(
+            upload_id, upload.filetype, upload.created_at.date()
+        )
     else:
         # Pour l'instant _collect_operations ne concerne que les états de
         # trésorerie, à terme quand nous voudrons présenter les comptes de
@@ -885,7 +902,7 @@ def scheduled_compile_measure_task(self, force=False):
     ACTIVATE THIS TASK IN CELERY'S INI CONFIG FILE IF NEEDED
     Eg:
         [celerybeat:accounting_measure_compute]
-        task = endi_celery.tasks.accounting_measure_compute.scheduled_compile_measure_task
+        task = endi_celery.tasks.accounting_measure_compute.scheduled_compile_measure_task  # NOQA: 905
         type = crontab
         schedule = {"minute": 0, "hour": 6}
     """
