@@ -122,7 +122,7 @@ def record_failure(job_model, job_id, e=None, **kwargs):
     job = _record_job_status(job_model, job_id, 'failed')
     # We append an error
     if hasattr(job, 'error_messages') and e:
-        job.error_messages = [u"%s" % e]
+        job.error_messages = e
 
     for key, value in kwargs.items():
         setattr(job, key, value)
